.. image:: https://raw.githubusercontent.com/openforis/sepal-doc/master/docs/source/img/sepal_header.png

Sepal_ui
--------

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
    :target: https://opensource.org/licenses/MIT
    :alt: License: MIT

.. image:: https://badge.fury.io/py/sepal-ui.svg
    :target: https://badge.fury.io/py/sepal-ui
    :alt: PyPI version

.. image:: https://travis-ci.com/12rambau/sepal_ui.svg?branch=master
    :target: https://travis-ci.com/12rambau/sepal_ui
    :alt: Build Status

.. image:: https://api.codeclimate.com/v1/badges/861f09002bb9d75b6ea5/maintainability
    :target: https://codeclimate.com/github/12rambau/sepal_ui/maintainability
    :alt: Maintainability

.. image:: https://codecov.io/gh/12rambau/sepal_ui/branch/master/graph/badge.svg?token=YZ3mVcuaCq
    :target: https://codecov.io/gh/12rambau/sepal_ui
    :alt: Test Coverage
    
.. image:: https://readthedocs.org/projects/sepal-ui/badge/?version=latest
    :target: https://sepal-ui.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

:code:`sepal_ui` is a lib designed to create elegant python based dashboard in the SEPAL environment. It is designed on top of the amazing `ipyvuetify <https://ipyvuetify.readthedocs.io/en/latest/introduction.html>`_ librairie and will help developper to easily create interface for their workflows. 
By using this librairy, you'll ensure a robust and unifyed interface for your scripts and a easy and complete integration into the SEPAL dashboard of application.

The full documentation is available here : `<https://sepal-ui.readthedocs.io/en/latest/>`_

We are happy to receive feedback and we welcome any kind of contribution

.. image:: https://raw.githubusercontent.com/12rambau/sepal_ui/master/docs/img/module-landing.png

Contribute
----------

If you want to contribute you can fork the project in you own repository and then use it. 
Please follow the `contributing guidelines <https://github.com/12rambau/sepal_ui/blob/master/CONTRIBUTE.md>`_ if you consider working with us. 
Meet our `contributor <https://github.com/12rambau/sepal_ui/blob/master/AUTHOR.rst>`_. 

